#!/bin/sh

# * Licensed Materials - Property of IBM
# * 5724-L68,5724-L69
# * (C) Copyright IBM Corp. 2006 - All Rights Reserved.
# * US Government Users Restricted Rights - Use, duplication or disclosure
# * restricted by GSA ADP Schedule Contract with IBM Corp.

## Step 1: Verify input params and give usage

if [ $# -lt 7 -o $# -gt 13 ]
then 
echo 1. Database user name
echo 2. Database user password
echo 3. Cutoff date YYYYMMDD
echo 4. Archive Task : COPY or DELETE
echo 5. Module: NONREP or MSGSTORE or COMMON
echo 6. Destination for the archive
echo 7. Partner Name
echo 8. Package Name
echo 9. Package Version
echo 10. Protocol Name
echo 11. Protocol Version
echo 12. Process Name
echo 13. Process Version

echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"

echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "

exit 1
fi

## Step 2: Input validations
nosofparams=$#
package=allO0oxyz
packageversion=allO0oxyz
protocol=allO0oxyz
protocolversion=allO0oxyz
process=allO0oxyz
processversion=allO0oxyz


userid=$1
shift
password=$1
shift
cutoffdate=$1

shift
archivetask=$1
shift
module=$1
shift
destination=$1
shift
partnervar=$1
if test "$partnervar" = "*"
	then
		partnervar='allO0oxyz'
fi

if test $nosofparams -gt 7
	then
		shift
		package=$1
		if test "$package" = "*"
			then
				package='allO0oxyz'
		fi
fi

if test $nosofparams -gt 8
	then
		shift
		packageversion=$1
		if test "$packageversion" = "*"
			then
				packageversion='allO0oxyz'
		fi
fi

if test $nosofparams -gt 9
	then
		shift
		protocol=$1
		if test "$protocol" = "*"
			then
				protocol='allO0oxyz'
		fi
fi

if test $nosofparams -gt 10
	then
		shift
		protocolversion=$1
		if test "$protocolversion" = "*"
			then
				protocolversion='allO0oxyz'
		fi
fi

if test $nosofparams -gt 11
	then
		shift
		process=$1
		if test "$process" = "*"
			then
				process='allO0oxyz'
		fi
fi

if test $nosofparams -gt 12
	then
		shift
		processversion=$1
		if test "$processversion" = "*"
			then
				processversion='allO0oxyz'
		fi
fi

## Convert input date format of YYYYMMDD format of YYYY-MM-DD and do the validations as well
if test ${#cutoffdate} -lt 8
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c1-4`
cutoffdateyy=$1
if test $cutoffdateyy -lt 2000
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c5,6`
cutoffdatemm=$1
if test $cutoffdatemm -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi

if test $cutoffdatemm -gt 12
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c7,8`
cutoffdatedd=$1
if test $cutoffdatedd -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi

if test $cutoffdatedd -gt 31
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgArchive <userid> <password> <cutoff date YYYYMMDD> <archive task: COPY|DELETE> <module: NONREP|MSGSTORE|COMMON> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgArchive db2inst1 pa55word 20050318 COPY NONREP /tmp/archive/20050318/  partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi

cutoffdateuse=${cutoffdateyy}-${cutoffdatemm}-${cutoffdatedd}

## Step 3: Set the environmant variables

BCGHUB_HOME="$BCGHUB_HOME$"

. "$BCGHUB_HOME"/bin/bcgSetupCmdLine.sh

DB_HOSTNAME=$DB_HOSTNAME$
DB_PORT=$DB_PORT$
DB_NAME=$DB_NAME$
DB_SCHEMA=$DB_SCHEMA$
DBTYPE=$DB_TYPE$
JDBC_QUAL=$DB_SCHEMA

JAVA_HOME=$BCGHUB_WAS_HOME/java

JDBC_DRIVER=$JDBC_DRIVER$


APP_LIB="$BCGHUB_HOME"/wasND/Profiles/"$RouterProfile"/installedApps/"$CellName"/BCGDocMgr.ear/lib/db2jcc.jar:"$BCGHUB_HOME"/wasND/Profiles/"$ConsoleProfile"/installedApps/"$CellName"/BCGConsole.ear/lib/db2jcc.jar:"$BCGHUB_HOME"/wasND/Profiles/"$ReceiverProfile"/installedApps/"$CellName"/BCGReceiver.ear/lib/db2jcc.jar


APP_CLASSPATH=$APP_LIB:$BCGHUB_HOME/bin/BcgArchive.jar
CLASSPATH=$APP_CLASSPATH:$CLASSPATH
## Changed for JR27370
##CLASSPATH=$CLASSPATH:$BCGHUB_WAS_HOME/lib/j2ee.jar:$BCGHUB_HOME/console/lib/support/db2jcc_license_cisuz.jar:$JDBC_DRIVER
CLASSPATH=$CLASSPATH:$BCGHUB_WAS_HOME/lib/j2ee.jar:$BCGHUB_HOME/wasND/Profiles/"$RouterProfile"/installedApps/"$CellName"/BCGDocMgr.ear/lib/db2jcc_license_cu.jar:$JDBC_DRIVER
## Changed for JR27370 - upto here.
export CLASSPATH
PATH=$PATH:$JAVA_HOME/bin
export PATH



if [ "$DBTYPE" = "ORACLE" ]
   then
    JDBC_DRIVER_CLASS=oracle.jdbc.OracleDriver
    JDBC_URL="jdbc:oracle:thin:@$DB_HOSTNAME:$DB_PORT:$DB_NAME"
   else
    JDBC_DRIVER_CLASS=com.ibm.db2.jcc.DB2Driver
    JDBC_URL="jdbc:db2://$DB_HOSTNAME:$DB_PORT/$DB_NAME"
fi


"$JAVA_HOME/bin/java"  -cp .:$JDBC_DRIVER:$CLASSPATH  com.ibm.bcg.db.util.DBArchiveMgmt "$JDBC_URL" "$JDBC_DRIVER_CLASS" "$userid" "$password" "$cutoffdateuse" "$archivetask" "$module" "$destination" "$DBTYPE" "$partnervar" "$package" "$packageversion" "$protocol" "$protocolversion" "$process" "$processversion"

exit 0
